@@ -9,7 +9,8 @@
 #' from R package \bold{metafor} (Viechtbauer 2010) is called
 #' internally.
 #' 
-#' @param event.e Number of events in experimental group.
+#' @param event.e Number of events in experimental group or an R object
+#'   created with \code{\link{pairwise}}.
 #' @param time.e Person time at risk in experimental group.
 #' @param event.c Number of events in control group.
 #' @param time.c Person time at risk in control group.
@@ -62,12 +63,18 @@
 #' @param method.tau.ci A character string indicating which method is
 #'   used to estimate the confidence interval of \eqn{\tau^2} and
 #'   \eqn{\tau} (see \code{\link{meta-package}}).
+#' @param level.hetstat The level used to calculate confidence intervals
+#'   for heterogeneity statistics.
 #' @param tau.preset Prespecified value for the square root of the
 #'   between-study variance \eqn{\tau^2}.
 #' @param TE.tau Overall treatment effect used to estimate the
 #'   between-study variance tau-squared.
 #' @param tau.common A logical indicating whether tau-squared should
 #'   be the same across subgroups.
+#' @param method.I2 A character string indicating which method is
+#'   used to estimate the heterogeneity statistic I\eqn{^2}. Either
+#'   \code{"Q"} or \code{"tau2"}, can be abbreviated
+#'   (see \code{\link{meta-package}}).
 #' @param level.ma The level used to calculate confidence intervals
 #'   for meta-analysis estimates.
 #' @param method.random.ci A character string indicating which method
@@ -119,8 +126,12 @@
 #' @param outclab Outcome label.
 #' @param label.e Label for experimental group.
 #' @param label.c Label for control group.
-#' @param label.left Graph label on left side of forest plot.
-#' @param label.right Graph label on right side of forest plot.
+#' @param label.left Graph label on left side of null effect in forest plot.
+#' @param label.right Graph label on right side of null effect in forest plot.
+#' @param col.label.left The colour of the graph label on the left side of
+#'   the null effect.
+#' @param col.label.right The colour of the graph label on the right side of
+#'   the null effect.
 #' @param subgroup An optional vector to conduct a meta-analysis with
 #'   subgroups.
 #' @param subgroup.name A character string with a name for the
@@ -177,7 +188,7 @@
 #' \code{VE = 100 * (1 - IRR)}.
 #' 
 #' A three-level random effects meta-analysis model (Van den Noortgate
-#' et al., 2013) is utilized if argument \code{cluster} is used and at
+#' et al., 2013) is utilised if argument \code{cluster} is used and at
 #' least one cluster provides more than one estimate. Internally,
 #' \code{\link[metafor]{rma.mv}} is called to conduct the analysis and
 #' \code{\link[metafor]{weights.rma.mv}} with argument \code{type =
@@ -418,9 +429,12 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
                                               nomatch = NA)),
                              "ML", gs("method.tau")),
                     method.tau.ci = gs("method.tau.ci"),
+                    level.hetstat = gs("level.hetstat"),
                     tau.preset = NULL, TE.tau = NULL,
                     tau.common = gs("tau.common"),
-                    ##
+                    #
+                    method.I2 = gs("method.I2"),
+                    #
                     level.ma = gs("level.ma"),
                     method.random.ci = gs("method.random.ci"),
                     adhoc.hakn.ci = gs("adhoc.hakn.ci"),
@@ -445,10 +459,13 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
                     ##
                     title = gs("title"), complab = gs("complab"),
                     outclab = "",
+                    #
                     label.e = gs("label.e"), label.c = gs("label.c"),
                     label.left = gs("label.left"),
                     label.right = gs("label.right"),
-                    ##
+                    col.label.left = gs("col.label.left"),
+                    col.label.right = gs("col.label.right"),
+                    #
                     subgroup, subgroup.name = NULL,
                     print.subgroup.name = gs("print.subgroup.name"),
                     sep.subgroup = gs("sep.subgroup"),
@@ -471,6 +488,45 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
   ## (1) Check arguments
   ##
   ##
+  
+  missing.sm <- missing(sm)
+  missing.subgroup <- missing(subgroup)
+  missing.byvar <- missing(byvar)
+  missing.overall <- missing(overall)
+  missing.overall.hetstat <- missing(overall.hetstat)
+  missing.test.subgroup <- missing(test.subgroup)
+  #
+  missing.event.c <- missing(event.c)
+  missing.time.e <- missing(time.e)
+  missing.time.c <- missing(time.c)
+  missing.n.e <- missing(n.e)
+  missing.n.c <- missing(n.c)
+  #
+  missing.studlab <- missing(studlab)
+  #
+  missing.incr <- missing(incr)
+  missing.method.incr <- missing(method.incr)
+  #
+  missing.method.tau <- missing(method.tau)
+  missing.tau.common <- missing(tau.common)
+  missing.method.predict <- missing(method.predict)
+  missing.method <- missing(method)
+  missing.level.ma <- missing(level.ma)
+  missing.common <- missing(common)
+  missing.random <- missing(random)
+  missing.method.random.ci <- missing(method.random.ci)
+  #
+  missing.hakn <- missing(hakn)
+  missing.adhoc.hakn.ci <- missing(adhoc.hakn.ci)
+  missing.adhoc.hakn <- missing(adhoc.hakn)
+  #
+  missing.subgroup.name <- missing(subgroup.name)
+  missing.print.subgroup.name <- missing(print.subgroup.name)
+  missing.sep.subgroup <- missing(sep.subgroup)
+  missing.complab <- missing(complab)
+  #
+  missing.cluster <- missing(cluster)
+  #
   chknumeric(rho, min = -1, max = 1)
   ##
   chknull(sm)
@@ -478,36 +534,32 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
   ##
   chklevel(level)
   ##
-  missing.method.tau <- missing(method.tau)
   method.tau <- setchar(method.tau, gs("meth4tau"))
   ##
   if (is.null(method.tau.ci))
     method.tau.ci <- if (method.tau == "DL") "J" else "QP"
   method.tau.ci <- setchar(method.tau.ci, gs("meth4tau.ci"))
   ##
-  missing.tau.common <- missing(tau.common)
   tau.common <- replaceNULL(tau.common, FALSE)
   chklogical(tau.common)
   ##
   chklogical(prediction)
   chklevel(level.predict)
   ##
-  missing.method.predict <- missing(method.predict)
   method.predict <- setchar(method.predict, gs("meth4pi"))
   ##
   method.tau <-
-    setmethodtau(method.tau, missing.method.tau,
+    set_method_tau(method.tau, missing.method.tau,
                  method.predict, missing.method.predict)
   method.predict <-
-    setmethodpredict(method.predict, missing.method.predict,
+    set_method_predict(method.predict, missing.method.predict,
                      method.tau, missing.method.tau)
   ##
   if (any(method.predict == "NNF"))
     is_installed_package("pimeta", argument = "method.predict", value = "NNF")
   ##
-  missing.adhoc.hakn.pi <- missing(adhoc.hakn.pi)
-  adhoc.hakn.pi <- setchar(adhoc.hakn.pi, gs("adhoc4hakn.pi"))
-  ##
+  adhoc.hakn.pi <- setchar(replaceNA(adhoc.hakn.pi, ""), gs("adhoc4hakn.pi"))
+  #
   method.bias <- setmethodbias(method.bias)
   ##
   chklogical(backtransf)
@@ -539,10 +591,8 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
     irscale <- 1
   }
   ##
-  missing.method <- missing(method)
   method <- setchar(method, gs("meth4inc"))
   ##
-  missing.method.incr <- missing(method.incr)
   method.incr <- setchar(method.incr, gs("meth4incr"))
   ##
   is.glmm <- method == "GLMM"
@@ -555,24 +605,25 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
   args  <- list(...)
   chklogical(warn.deprecated)
   ##
-  level.ma <- deprecated(level.ma, missing(level.ma), args, "level.comb",
+  level.ma <- deprecated(level.ma, missing.level.ma, args, "level.comb",
                          warn.deprecated)
   chklevel(level.ma)
-  ##
-  missing.common <- missing(common)
+  #
+  method.I2 <- setchar(method.I2, gs("meth4i2"))
+  #
   common <- deprecated(common, missing.common, args, "comb.fixed",
                        warn.deprecated)
   common <- deprecated(common, missing.common, args, "fixed",
                        warn.deprecated)
   chklogical(common)
   ##
-  random <- deprecated(random, missing(random), args, "comb.random",
+  random <- deprecated(random, missing.random, args, "comb.random",
                        warn.deprecated)
   chklogical(random)
   ##
   method.random.ci <-
-    deprecated2(method.random.ci, missing(method.random.ci),
-                hakn, missing(hakn),
+    deprecated2(method.random.ci, missing.method.random.ci,
+                hakn, missing.hakn,
                 warn.deprecated)
   if (is.logical(method.random.ci))
     if (method.random.ci)
@@ -581,51 +632,28 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
       method.random.ci <- "classic"
   method.random.ci <- setchar(method.random.ci, gs("meth4random.ci"))
   ##
-  missing.adhoc.hakn.ci <- missing(adhoc.hakn.ci)
   adhoc.hakn.ci <-
     deprecated2(adhoc.hakn.ci, missing.adhoc.hakn.ci,
-                adhoc.hakn, missing(adhoc.hakn), warn.deprecated)
-  adhoc.hakn.ci <- setchar(adhoc.hakn.ci, gs("adhoc4hakn.ci"))
-  ##
-  missing.subgroup.name <- missing(subgroup.name)
+                adhoc.hakn, missing.adhoc.hakn, warn.deprecated)
+  adhoc.hakn.ci <- setchar(replaceNA(adhoc.hakn.ci, ""), gs("adhoc4hakn.ci"))
+  #
   subgroup.name <-
     deprecated(subgroup.name, missing.subgroup.name, args, "bylab",
                warn.deprecated)
   ##
   print.subgroup.name <-
-    deprecated(print.subgroup.name, missing(print.subgroup.name),
+    deprecated(print.subgroup.name, missing.print.subgroup.name,
                args, "print.byvar", warn.deprecated)
   print.subgroup.name <-
     replaceNULL(print.subgroup.name, gs("print.subgroup.name"))
   chklogical(print.subgroup.name)
   ##
   sep.subgroup <-
-    deprecated(sep.subgroup, missing(sep.subgroup), args, "byseparator",
+    deprecated(sep.subgroup, missing.sep.subgroup, args, "byseparator",
                warn.deprecated)
   if (!is.null(sep.subgroup))
     chkchar(sep.subgroup, length = 1)
   ##
-  addincr <-
-    deprecated(method.incr, missing.method.incr, args, "addincr",
-               warn.deprecated)
-  allincr <-
-    deprecated(method.incr, missing.method.incr, args, "allincr",
-               warn.deprecated)
-  if (missing.method.incr) {
-    method.incr <- gs("method.incr")
-    ##
-    if (is.logical(addincr) && addincr)
-      method.incr <- "all"
-    else if (is.logical(allincr) && allincr)
-      method.incr <- "if0all"
-  }
-  ##
-  addincr <- allincr <- FALSE
-  if (method.incr == "all")
-    addincr <- TRUE
-  else if (method.incr == "if0all")
-    allincr <- TRUE
-  ##
   ## Some more checks
   ##
   chklogical(overall)
@@ -637,56 +665,184 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
   ## (2) Read data
   ##
   ##
+  
   nulldata <- is.null(data)
   sfsp <- sys.frame(sys.parent())
   mc <- match.call()
   ##
   if (nulldata)
     data <- sfsp
-  ##
-  ## Catch 'event.e', 'time.e', 'event.c', 'time.c', 'n.e', and 'n.c'
-  ## from data:
-  ##
+  #
+  # Catch 'event.e', 'time.e', 'event.c', 'time.c', 'n.e', 'n.c', 'studlab',
+  # and 'subgroup' from data:
+  #
   event.e <- catch("event.e", mc, data, sfsp)
   chknull(event.e)
+  #
+  if (is.data.frame(event.e) & !is.null(attr(event.e, "pairwise"))) {
+    type <- attr(event.e, "type")
+    if (type != "count")
+      stop("Wrong type for pairwise() object: '", type, "'.", call. = FALSE)
+    #
+    is.pairwise <- TRUE
+    #
+    txt.ignore <- "ignored as first argument is a pairwise object"
+    #
+    ignore_input(event.c, !missing.event.c, txt.ignore)
+    ignore_input(time.e, !missing.time.e, txt.ignore)
+    ignore_input(time.c, !missing.time.c, txt.ignore)
+    ignore_input(n.e, !missing.n.e, txt.ignore)
+    ignore_input(n.c, !missing.n.c, txt.ignore)
+    ignore_input(subgroup, !missing.subgroup, txt.ignore)
+    #
+    missing.event.c <- FALSE
+    missing.time.e <- FALSE
+    missing.time.c <- FALSE
+    missing.n.e <- FALSE
+    missing.n.c <- FALSE
+    #
+    if (missing.sm)
+      sm <- attr(event.e, "sm")
+    #
+    if (missing.incr)
+      incr <- attr(event.e, "incr")
+    if (missing.method.incr)
+      method.incr <- attr(event.e, "method.incr")
+    #
+    missing.incr <- FALSE
+    missing.method.incr <- FALSE
+    #
+    reference.group <- attr(event.e, "reference.group")
+    #
+    studlab <- event.e$studlab
+    #
+    treat1 <- event.e$treat1
+    treat2 <- event.e$treat2
+    #
+    event.c <- event.e$event2
+    #
+    time.e <- event.e$time1
+    time.c <- event.e$time2
+    #
+    n.e <- event.e$n1
+    n.c <- event.e$n2
+    #
+    pairdata <- event.e
+    data <- event.e
+    nulldata <- FALSE
+    #
+    event.e <- event.e$event1
+    #
+    wo <- treat1 == reference.group
+    #
+    if (any(wo)) {
+      ttreat1 <- treat1
+      treat1[wo] <- treat2[wo]
+      treat2[wo] <- ttreat1[wo]
+      #
+      tevent.e <- event.e
+      event.e[wo] <- event.c[wo]
+      event.c[wo] <- tevent.e[wo]
+      #
+      tevent.e <- event.e
+      event.e[wo] <- event.c[wo]
+      event.c[wo] <- tevent.e[wo]
+      #
+      if (!(is.null(n.e) | is.null(n.c))) {
+        tn.e <- n.e
+        n.e[wo] <- n.c[wo]
+        n.c[wo] <- tn.e[wo]
+      }
+    }
+    #
+    if (missing.subgroup) {
+      #subgroup <- paste(paste0("'", treat1, "'"),
+      #                  paste0("'", treat2, "'"),
+      #                  sep = " vs ")
+      subgroup <- paste(treat1, treat2, sep = " vs ")
+      #
+      if (length(unique(subgroup)) == 1) {
+        if (missing.complab)
+          complab <- unique(subgroup)
+        #
+        subgroup <- NULL
+      }
+      else {
+        if (missing.overall)
+          overall <- FALSE
+        if (missing.overall.hetstat)
+          overall.hetstat <- FALSE
+        if (missing.test.subgroup)
+          test.subgroup <- FALSE
+      }
+    }
+    else
+      subgroup <- catch("subgroup", mc, data, sfsp)
+  }
+  else {
+    is.pairwise <- FALSE
+    #
+    if (missing.sm && !is.null(data) && !is.null(attr(data, "sm")))
+      sm <- attr(data, "sm")
+    #
+    time.e <- catch("time.e", mc, data, sfsp)
+    n.e <- catch("n.e", mc, data, sfsp)
+    #
+    event.c <- catch("event.c", mc, data, sfsp)
+    time.c <- catch("time.c", mc, data, sfsp)
+    n.c <- catch("n.c", mc, data, sfsp)
+    #
+    studlab <- catch("studlab", mc, data, sfsp)
+    #
+    subgroup <- catch("subgroup", mc, data, sfsp)
+    byvar <- catch("byvar", mc, data, sfsp)
+    #
+    subgroup <- deprecated2(subgroup, missing.subgroup, byvar, missing.byvar,
+                            warn.deprecated)
+    #
+    if (!missing.incr)
+      incr <- catch("incr", mc, data, sfsp)
+  }
+  #
+  addincr <-
+    deprecated(method.incr, missing.method.incr, args, "addincr",
+               warn.deprecated)
+  allincr <-
+    deprecated(method.incr, missing.method.incr, args, "allincr",
+               warn.deprecated)
+  #
+  if (missing.method.incr) {
+    method.incr <- gs("method.incr")
+    ##
+    if (is.logical(addincr) && addincr)
+      method.incr <- "all"
+    else if (is.logical(allincr) && allincr)
+      method.incr <- "if0all"
+  }
+  #
+  addincr <- allincr <- FALSE
+  if (method.incr == "all")
+    addincr <- TRUE
+  else if (method.incr == "if0all")
+    allincr <- TRUE
+  #
   k.All <- length(event.e)
-  ##
-  time.e <- catch("time.e", mc, data, sfsp)
+  #
   chknull(time.e)
-  ##
-  event.c <- catch("event.c", mc, data, sfsp)
   chknull(event.c)
-  ##
-  time.c <- catch("time.c", mc, data, sfsp)
   chknull(time.c)
   ##
-  n.e <- catch("n.e", mc, data, sfsp)
   null.n.e <- is.null(n.e)
-  ##
-  n.c <- catch("n.c", mc, data, sfsp)
   null.n.c <- is.null(n.c)
-  ##
-  ## Catch 'incr' from data:
-  ##
-  if (!missing(incr))
-    incr <- catch("incr", mc, data, sfsp)
+  #
   chknumeric(incr, min = 0)
-  ##
-  ## Catch 'studlab', 'subgroup', 'subset', 'exclude' and 'cluster'
-  ## from data:
-  ##
-  studlab <- catch("studlab", mc, data, sfsp)
+  #
   studlab <- setstudlab(studlab, k.All)
-  ##
-  missing.subgroup <- missing(subgroup)
-  subgroup <- catch("subgroup", mc, data, sfsp)
-  missing.byvar <- missing(byvar)
-  byvar <- catch("byvar", mc, data, sfsp)
-  ##
-  subgroup <- deprecated2(subgroup, missing.subgroup, byvar, missing.byvar,
-                          warn.deprecated)
+  #
   by <- !is.null(subgroup)
-  ##
+  #
+  # Catch 'subset', 'exclude' and 'cluster' from data:
+  #
   subset <- catch("subset", mc, data, sfsp)
   missing.subset <- is.null(subset)
   ##
@@ -702,6 +858,7 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
   ## (3) Check length of essential variables
   ##
   ##
+  
   chklength(time.e, k.All, fun)
   chklength(event.c, k.All, fun)
   chklength(time.c, k.All, fun)
@@ -744,6 +901,7 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
   ## (4) Subset, exclude studies, and subgroups
   ##
   ##
+  
   if (!missing.subset)
     if ((is.logical(subset) & (sum(subset) > k.All)) ||
         (length(subset) > k.All))
@@ -768,6 +926,7 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
   ##     (if argument keepdata is TRUE)
   ##
   ##
+  
   if (keepdata) {
     if (nulldata)
       data <- data.frame(.event.e = event.e)
@@ -808,6 +967,7 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
   ## (6) Use subset for analysis
   ##
   ##
+  
   if (!missing.subset) {
     event.e <- event.e[subset]
     time.e <- time.e[subset]
@@ -881,6 +1041,7 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
   ## (7) Calculate results for individual studies
   ##
   ##
+  
   sel <- switch(sm,
                 IRD = event.e == 0 | event.c == 0,
                 IRR = event.e == 0 | event.c == 0,
@@ -923,6 +1084,7 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
   ## (8) Additional checks for three-level model
   ##
   ##
+  
   three.level <- FALSE
   sel.ni <- !is.infinite(TE) & !is.infinite(seTE)
   ##
@@ -952,6 +1114,7 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
   ## (9) Additional checks for GLMMs
   ##
   ##
+  
   if (is.glmm) {
     chkglmm(sm, method.tau, method.random.ci, method.predict,
             adhoc.hakn.ci, adhoc.hakn.pi,
@@ -972,7 +1135,7 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
     }
     ##
     if (sparse)
-      if ((!missing(incr) & any(incr != 0)) |
+      if ((!missing.incr & any(incr != 0)) |
           allincr | addincr)
         warning("Note, for method = \"GLMM\", continuity correction only ",
                 "used to calculate individual study results.",
@@ -985,6 +1148,7 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
   ## (10) Do meta-analysis
   ##
   ##
+  
   k <- sum(!is.na(event.e[!exclude]) & !is.na(event.c[!exclude]) &
            !is.na(time.e[!exclude]) & !is.na(time.c[!exclude]))
   ##
@@ -1087,10 +1251,13 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
                prediction = prediction,
                ##
                method.tau = method.tau, method.tau.ci = method.tau.ci,
+               level.hetstat = level.hetstat,
                tau.preset = tau.preset,
                TE.tau = TE.tau,
                tau.common = FALSE,
-               ##
+               #
+               method.I2 = method.I2,
+               #
                level.ma = level.ma,
                method.random.ci = method.random.ci,
                adhoc.hakn.ci = adhoc.hakn.ci,
@@ -1109,27 +1276,31 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
                text.w.common = text.w.common, text.w.random = text.w.random,
                ##
                title = title, complab = complab, outclab = outclab,
+               #
                label.e = label.e, label.c = label.c,
                label.left = label.left, label.right = label.right,
-               ##
+               col.label.left = col.label.left,
+               col.label.right = col.label.right,
+               #
                keepdata = FALSE,
                warn = warn,
                ##
                control = control)
-  ##
-  if (by & tau.common & !is.glmm) {
-    ## Estimate common tau-squared across subgroups
+  #
+  # Estimate common tau-squared across subgroups
+  #
+  if (by & tau.common & !is.glmm)
     hcc <- hetcalc(TE, seTE, method.tau, "",
                    if (method == "Inverse") TE.tau else TE.common,
-                   level.ma, subgroup, control)
-  }
+                   method.I2, level.hetstat, subgroup, control)
   
   
   ##
   ##
-  ## (9) Generate R object
+  ## (11) Generate R object
   ##
   ##
+  
   res <- list(event.e = event.e, time.e = time.e,
               event.c = event.c, time.c = time.c,
               method = method, method.random = method,
@@ -1175,7 +1346,7 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
   }
   ##
   if (is.glmm) {
-    res <- addGLMM(res, res.glmm)
+    res <- addGLMM(res, res.glmm, method.I2)
     res$model.glmm <- model.glmm
     ##
     if (by) {
@@ -1201,7 +1372,8 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
                       as.call(~ subgroup.glmm)
                     else
                       NULL,
-                  control = control, use.random = use.random)$glmm.random[[1]]
+                  control = control, use.random = use.random)$glmm.random[[1]],
+          method.I2
         )
     }
   }
